export default {
  "bootstrapScriptContent": "import(\"/assets/index-nUoa9IYd.js\")",
  "clientReferenceDeps": {
    "1fd1e9347369": {
      "js": [
        "/assets/site-shell--2UFGXf4.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/index-nUoa9IYd.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "4e07333fa9b7": {
      "js": [
        "/assets/page-CyfsiQsn.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/site-shell--2UFGXf4.js",
        "/assets/index-nUoa9IYd.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "8f7ba5393f33": {
      "js": [
        "/assets/index-nUoa9IYd.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "ee6cb3d92c61": {
      "js": [
        "/assets/layout-segment-context-DUgFMV95.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/index-nUoa9IYd.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    },
    "1e6222746775": {
      "js": [
        "/assets/index-nUoa9IYd.js",
        "/assets/rolldown-runtime-S-ySWqyJ.js",
        "/assets/framework-DjPHiq1u.js"
      ],
      "css": []
    }
  },
  "serverResources": {
    "app/layout.tsx": {
      "js": [],
      "css": [
        "/assets/index-PtNyZlk5.css"
      ]
    }
  }
}