import{r as e}from"./rolldown-runtime-S-ySWqyJ.js";import{i as t}from"./framework-DjPHiq1u.js";import{r as n}from"./index-nUoa9IYd.js";var r=e(t(),1);function i({segmentMap:e,children:t}){let i=n();return i?(0,r.createElement)(i.Provider,{value:e},t):t}export{i as LayoutSegmentProvider};